==> phyloraster_2.0.1.tar.gz: phyloraster/README.md <==
<!-- badges: start -->

[![R-CMD-check](https://github.com/gabferreira/phyloraster/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/gabferreira/phyloraster/actions/workflows/R-CMD-check.yaml)
[![codecov](https://codecov.io/gh/gabferreira/phyloraster/branch/master/graph/badge.svg)](https://app.codecov.io/gh/gabferreira/phyloraster)
<!-- badges: end -->

# phyloraster <a href="https://gabferreira.github.io/phyloraster/"><img src="man/figures/logo.png" alt="phyloraster website" align="right" height="139"/></a>

<br>

[`phyloraster`](https://github.com/gabferreira/phyloraster) is an R package to calculate measures of endemism and evolutionary diversity using rasters of presence-absence as input, allowing to join the results derived from species distribution models (SDMs) with phylogenetic information.

<br>

### Installation

The CRAN version of the package can be installed using:
```
install.packages("phyloraster") 
```

The development version of `phyloraster` can be downloaded from [GitHub](https://github.com/gabferreira/phyloraster) using the following code:
```
devtools::install_github("gabferreira/phyloraster")
```

<br>

### phyloraster basics

Basic information about the package can be found at the [package's webpage](https://gabferreira.github.io/phyloraster/) or in the vignette `vignette("phyloraster-vignette")`

<br>

### Citation

- If you use this R package, please cite in your publications: <br>

Alves-Ferreira G., Heming N. M., Mota F. M. M. (2023). phyloraster: Evolutionary Diversity Metrics for Raster Data. R package version 2.0.

- For more information:

```         
citation("phyloraster")
```

<br>

### Issues

If you have any question or find any bug, let us know through the topic ["Issues"](https://github.com/gabferreira/phyloraster/issues).

<br>

==> phyloraster_2.1.0.tar.gz: phyloraster/README.md <==
<!-- badges: start -->
[![CRAN-status](https://www.r-pkg.org/badges/version/phyloraster)](https://cran.r-project.org/package=phyloraster)
[![R-CMD-check](https://github.com/gabferreira/phyloraster/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/gabferreira/phyloraster/actions/workflows/R-CMD-check.yaml)
[![codecov](https://codecov.io/gh/gabferreira/phyloraster/branch/master/graph/badge.svg)](https://app.codecov.io/gh/gabferreira/phyloraster)
[![download](http://cranlogs.r-pkg.org/badges/grand-total/phyloraster?color=green)](https://cran.r-project.org/package=phyloraster)
[![download per month](http://cranlogs.r-pkg.org/badges/phyloraster?color=green)](https://cran.r-project.org/package=phyloraster)
<!-- badges: end -->

# phyloraster <a href="https://gabferreira.github.io/phyloraster/"><img src="man/figures/logo.png" alt="phyloraster website" align="right" height="139"/></a>

<br>

[`phyloraster`](https://github.com/gabferreira/phyloraster) is an R package to calculate measures of endemism and evolutionary diversity using rasters of presence-absence as input, allowing to join the results derived from species distribution models (SDMs) with phylogenetic information.

<br>

### Installation

The CRAN version of the package can be installed using:
```
install.packages("phyloraster") 
```

The development version of `phyloraster` can be downloaded from [GitHub](https://github.com/gabferreira/phyloraster) using the following code:
```
devtools::install_github("gabferreira/phyloraster")
```

<br>

### phyloraster basics

Basic information about the package can be found at the [package's webpage](https://gabferreira.github.io/phyloraster/) or in the vignette `vignette("phyloraster-vignette")`

<br>

### Citation

- Thank you for using phyloraster! Please remember to cite phyloraster in your publications: <br>

Alves-Ferreira G., Heming N. M., Mota F. M. M. (2023). phyloraster: Evolutionary Diversity Metrics for Raster Data. R package version 2.0.

Alves-Ferreira G, Mota FMM, Talora DC, Oliveira, C, Solé, MK, Heming NM (2023). phyloraster: an R package to calculate measures of endemism and evolutionary diversity for rasters. Ecography. doi: 10.1111/ecog.06902. 

- For more information:

```         
citation("phyloraster")
```

<br>

### Issues

If you have any question or find any bug, let us know through the topic ["Issues"](https://github.com/gabferreira/phyloraster/issues).

<br>
